package WebGUI::i18n::German::Asset_GalleryAlbum;
use utf8;
our $I18N = {
  'Adding %s to album' => {
    'lastUpdated' => '1254902440',
    'message' => 'Dem Album %s hinzufügen'
  },
  'Extracting archive' => {
    'lastUpdated' => '1254902451',
    'message' => 'Archiv entpacken'
  },
  'Found file: %s' => {
    'lastUpdated' => '1254902470',
    'message' => 'Gefundene Datei: %s'
  },
  'Getting list of files for sorting purposes' => {
    'lastUpdated' => '1285235214',
    'message' => 'Dateiliste fürs Sortieren holen.'
  },
  'Requesting commit for version tag' => {
    'lastUpdated' => '1254902486',
    'message' => 'Commit für Versions-Tag anfordern'
  },
  'Uploading archive' => {
    'lastUpdated' => '1254902501',
    'message' => 'Archiv hochladen'
  },
  'add photo' => {
    'lastUpdated' => '1244063236',
    'message' => 'Bild hinzufügen'
  },
  'addArchive error generic' => {
    'lastUpdated' => '1229104620',
    'message' => 'Beim Hochladen Ihres Archivs kam es zu folgendem Fehler: %s'
  },
  'addArchive error too big' => {
    'lastUpdated' => '1201601843',
    'message' => 'Das Archiv, das Sie versuchen hochzuladen ist zu groß. Bitte versuchen Sie es erneut.'
  },
  'addArchive file' => {
    'lastUpdated' => '1229104654',
    'message' => 'Archiv'
  },
  'addArchive friendsOnly' => {
    'lastUpdated' => '1229104679',
    'message' => 'Nur Freunde'
  },
  'addArchive keywords' => {
    'lastUpdated' => '1229104725',
    'message' => 'Stichwörter'
  },
  'addArchive location' => {
    'lastUpdated' => '1274268629',
    'message' => 'Ort'
  },
  'addArchive message' => {
    'lastUpdated' => '1229372718',
    'message' => 'Ihre Dateien wurden für die Freigabe und Veröffentlichung eingereicht. <a href="%s">Zurück zum Album</a>'
  },
  'addArchive sortBy' => {
    'lastUpdated' => '1274268639',
    'message' => 'Sortieren nach'
  },
  'addArchive sortBy date' => {
    'lastUpdated' => '1274268646',
    'message' => 'Datum'
  },
  'addArchive sortBy fileOrder' => {
    'lastUpdated' => '1274268663',
    'message' => 'Dateireihenfolge'
  },
  'addArchive sortBy name' => {
    'lastUpdated' => '1274268671',
    'message' => 'Name'
  },
  'assetName' => {
    'lastUpdated' => '1229109426',
    'message' => 'Galerie-Album'
  },
  'cancel' => {
    'lastUpdated' => '1201602049',
    'message' => 'Abbrechen'
  },
  'delete message' => {
    'lastUpdated' => '1229712882',
    'message' => 'Das Album wurde gelöscht. <a href="%s">Zurück zur Galerie</a>'
  },
  'editForm assetIdThumbnail label' => {
    'lastUpdated' => '1231259504',
    'message' => 'Bitte wählen Sie ein Vorschaubild, das Ihr Album repräsentieren soll.'
  },
  'editForm description label' => {
    'lastUpdated' => '1230111188',
    'message' => 'Beschreibung'
  },
  'editForm othersCanAdd label' => {
    'lastUpdated' => '1229104991',
    'message' => 'Andere können hinzufügen'
  },
  'editForm title label' => {
    'lastUpdated' => '1229105002',
    'message' => 'Titel'
  },
  'help addArchive body' => {
    'lastUpdated' => '1229374086',
    'message' => 'Diese Variablen sind in der "Archiv hinzufügen"-Ansicht des Albums verfügbar.'
  },
  'help addArchive title' => {
    'lastUpdated' => '1231259246',
    'message' => 'Galerie-Album, Archiv hinzufügen'
  },
  'help common body' => {
    'lastUpdated' => '1229374113',
    'message' => 'Diese Variablen sind in allen Ansichten des Albums verfügbar.'
  },
  'help common title' => {
    'lastUpdated' => '1231259313',
    'message' => 'Galerie-Album, allgemein'
  },
  'help delete body' => {
    'lastUpdated' => '1229374185',
    'message' => 'Diese Variablen sind in der "Album löschen"-Ansicht des Albums verfügbar.'
  },
  'help delete title' => {
    'lastUpdated' => '1231259113',
    'message' => 'Galerie-Album, löschen'
  },
  'help edit body' => {
    'lastUpdated' => '1229374068',
    'message' => 'Diese Variablen sind in der "Album bearbeiten"-Ansicht des Albums verfügbar.'
  },
  'help edit title' => {
    'lastUpdated' => '1231259341',
    'message' => 'Galerie-Album, bearbeiten'
  },
  'help fileLoop body' => {
    'lastUpdated' => '1229373999',
    'message' => 'Diese Variablen sind in allen Ansichten verfügbar, die eine Schleife über Dateien bilden.'
  },
  'help fileLoop title' => {
    'lastUpdated' => '1231259529',
    'message' => 'Galerie-Album, Dateischleife'
  },
  'help slideshow body' => {
    'lastUpdated' => '1229373935',
    'message' => 'Diese Variablen sind in der Diashow-Ansicht des Albums verfügbar.'
  },
  'help slideshow title' => {
    'lastUpdated' => '1231361554',
    'message' => 'Galerie-Album, Diashow'
  },
  'help thumbnails body' => {
    'lastUpdated' => '1229373861',
    'message' => 'Diese Variablen sind in der Vorschaubild-Ansicht des Albums verfügbar.'
  },
  'help thumbnails title' => {
    'lastUpdated' => '1231361577',
    'message' => 'Galerie-Album, Vorschaubilder'
  },
  'help view body' => {
    'lastUpdated' => '1229373779',
    'message' => 'Diese Variablen sind in der Albenansicht des Albums verfügbar.'
  },
  'help view title' => {
    'lastUpdated' => '1231259368',
    'message' => 'Galerie-Album, Albenansicht'
  },
  'help viewRss body' => {
    'lastUpdated' => '1229374309',
    'message' => 'Diese Variablen sind innerhalb des RSS-Feeds des Albums verfügbar.'
  },
  'help viewRss title' => {
    'lastUpdated' => '1231259790',
    'message' => 'Galerie-Album, RSS-Feed'
  },
  'helpvar canAddFile' => {
    'lastUpdated' => '1229713170',
    'message' => 'Variable die wahr ist, falls ein Benutzer Dateien zu diesem Album hinzufügen darf.'
  },
  'helpvar canEdit' => {
    'lastUpdated' => '1229713204',
    'message' => 'Variable die wahr ist, falls ein Benutzer das Album bearbeiten darf.'
  },
  'helpvar error' => {
    'lastUpdated' => '1229373583',
    'message' => 'Fehlermeldung für den Benutzer. Die Variable ist nur definiert, falls ein Fehler aufgetreten ist.'
  },
  'helpvar fileCount' => {
    'lastUpdated' => '1229373530',
    'message' => 'Die Anzahl der Dateien in diesem Album.'
  },
  'helpvar file_' => {
    'lastUpdated' => '1229993185',
    'message' => 'Die aktuelle Datei, die auf der Vorschaubild-Seite angezeigt wird. Alle allgemeinen Variablen dieser Datei sind verfügbar &uuml;ber den Präfix &quot;file_&quot;.'
  },
  'helpvar file_*' => {
    'lastUpdated' => '1235678893',
    'message' => 'Alle allgemeinen Variablen des gegenwärtig dargestellten Bildes in der Vorschauansicht; modifiziert durch den Päfix "file_".'
  },
  'helpvar file_loop' => {
    'lastUpdated' => '1231361930',
    'message' => 'Schleife über die Dateien auf der angezeigten Seite.'
  },
  'helpvar file_loop edit' => {
    'lastUpdated' => '1229373383',
    'message' => 'Schleife über die Dateien für die Bearbeitung mehrere Dateien in der "Album bearbeiten"-Ansicht.'
  },
  'helpvar file_loop viewRss' => {
    'lastUpdated' => '1231259466',
    'message' => 'Schleife über die Dateien für den RSS-Feed, die zusätzliche Variablen enthält.'
  },
  'helpvar form_archive' => {
    'lastUpdated' => '1229373237',
    'message' => 'Hochzuladendes Archiv. Ein WebGUI::Form::File-Kontrollelement.'
  },
  'helpvar form_cancel' => {
    'lastUpdated' => '1201603216',
    'message' => 'Formular abbrechen.'
  },
  'helpvar form_delete' => {
    'lastUpdated' => '1229105031',
    'message' => 'Eine Schaltfläche, um das Bild zu löschen.'
  },
  'helpvar form_demote' => {
    'lastUpdated' => '1229105145',
    'message' => 'Eine Schaltfläche, um das Bild in der Reihenfolge nach unten zu bewegen. Benutzen Sie diese, um die Anordnung der Bilder zu ändern.'
  },
  'helpvar form_description' => {
    'lastUpdated' => '1229713100',
    'message' => 'Die Beschreibung des Albums.'
  },
  'helpvar form_end' => {
    'lastUpdated' => '1201603251',
    'message' => 'Ende des Formulars'
  },
  'helpvar form_friendsOnly' => {
    'lastUpdated' => '1229373144',
    'message' => 'Datei nur für Freunde?'
  },
  'helpvar form_keywords' => {
    'lastUpdated' => '1229373174',
    'message' => 'Stichwörter für die hochzuladende Datei.'
  },
  'helpvar form_location' => {
    'lastUpdated' => '1274268704',
    'message' => 'Der Ort der hochzuladenden Dateien.'
  },
  'helpvar form_promote' => {
    'lastUpdated' => '1229105278',
    'message' => 'Eine Schaltfläche, um das Bild in der Reihenfolge nach oben zu bewegen. Benutzen Sie diese, um die Anordnung der Bilder zu ändern.'
  },
  'helpvar form_rotateLeft' => {
    'lastUpdated' => '1271833983',
    'message' => 'Ein Button, um das Bild um 90° gegen den Uhrzeigersinn zu drehen.'
  },
  'helpvar form_rotateRight' => {
    'lastUpdated' => '1271833956',
    'message' => 'Ein Button, um das Bild um 90° im Uhrzeigersinn zu drehen.'
  },
  'helpvar form_sortBy' => {
    'lastUpdated' => '1274268732',
    'message' => 'Eigenschaft nach der Fotos sortiert werden sollen.'
  },
  'helpvar form_start' => {
    'lastUpdated' => '1201603314',
    'message' => 'Beginn des Formulars'
  },
  'helpvar form_submit' => {
    'lastUpdated' => '1201603337',
    'message' => 'Submit Formular'
  },
  'helpvar form_synopsis' => {
    'lastUpdated' => '1229105336',
    'message' => 'Eine HTML-Fläche zur Beschriftung des Vorschaubilds.'
  },
  'helpvar form_title' => {
    'lastUpdated' => '1201603354',
    'message' => 'Der Titel des Albums.'
  },
  'helpvar gallery_displayTitle' => {
    'lastUpdated' => '1235679010',
    'message' => 'Eine Variable die wahr ist, falls der Titel der Galerie, welche diese Datei enthält, angezeigt wird.'
  },
  'helpvar gallery_menuTitle' => {
    'lastUpdated' => '1229993280',
    'message' => 'Der Menütitel der Galerie, die diese Datei enthält.'
  },
  'helpvar gallery_title' => {
    'lastUpdated' => '1229993303',
    'message' => 'Der Titel der Galerie, die diese Datei enthält.'
  },
  'helpvar gallery_url' => {
    'lastUpdated' => '1229992993',
    'message' => 'Der URL zur Galerie, die diese Datei enthält.'
  },
  'helpvar isAlbumThumbnail' => {
    'lastUpdated' => '1229713070',
    'message' => 'Variable die wahr ist, falls die Datei das aktuelle Vorschaubild des Albums ist.'
  },
  'helpvar isNewAlbum' => {
    'lastUpdated' => '1229993025',
    'message' => 'Variable die wahr ist, falls der Benutzer ein neues Album in der Galerie anlegt.'
  },
  'helpvar isPending' => {
    'lastUpdated' => '1229993104',
    'message' => 'Variable die wahr ist, falls das Album noch nicht freigegeben wurde. Benutzer, die das Recht zur Bearbeitung haben, können es jedoch schon vorab sehen.'
  },
  'helpvar nextAlbum_thumbnailUrl' => {
    'lastUpdated' => '1229105929',
    'message' => 'Der URL zum Vorschaubild des nächsten Albums in der Liste.'
  },
  'helpvar nextAlbum_title' => {
    'lastUpdated' => '1229105949',
    'message' => 'Der Titel des nächsten Albums in der Liste.'
  },
  'helpvar nextAlbum_url' => {
    'lastUpdated' => '1229993045',
    'message' => 'Der URL zum nächsten Album, ausgehend von der Reihenfolge, wie sie in der Listenansicht der Galerie zu sehen ist. Diese Variable existiert nicht, falls es kein weiteres Album gibt.'
  },
  'helpvar ownerUsername' => {
    'lastUpdated' => '1231362104',
    'message' => 'Der Benutzername des Besitzers des aktuellen Albums.'
  },
  'helpvar previousAlbum_thumbnailUrl' => {
    'lastUpdated' => '1229106236',
    'message' => 'Der URL zum Vorschaubild des vorherigen Albums in der Liste.'
  },
  'helpvar previousAlbum_title' => {
    'lastUpdated' => '1229106253',
    'message' => 'Der Titel des vorherigen Albums in der Liste.'
  },
  'helpvar previousAlbum_url' => {
    'lastUpdated' => '1229993063',
    'message' => 'Der URL zum vorhergehenden Album, ausgehend von der Reihenfolge, wie sie in der Listenansicht der Galerie zu sehen ist. Diese Variable existiert nicht, falls es kein vorhergehendes Album gibt.'
  },
  'helpvar rssDate' => {
    'lastUpdated' => '1201603467',
    'message' => 'Das RFC-2822-konforme Datum des RSS Feed.'
  },
  'helpvar thumbnailUrl' => {
    'lastUpdated' => '1229370916',
    'message' => 'Der URL zum Vorschaubild der Datei, die als Vorschaubild für dieses Album ausgewählt wurde.'
  },
  'helpvar url_addArchive' => {
    'lastUpdated' => '1229371056',
    'message' => 'Der URL zum Hinzufügen eines Archivs mit Dateien zu diesem Album.'
  },
  'helpvar url_addNoClass' => {
    'lastUpdated' => '1229371218',
    'message' => 'Der URL zum Hinzufügen eines beliegen Objekts zu diesem Album. Sie müssen die Klasse durch Anhängen von ";class=Class::<Name>" spezifizieren.'
  },
  'helpvar url_addPhoto' => {
    'lastUpdated' => '1229371082',
    'message' => 'Der URL zum hinzufügen eines Fotos zu diesem Album.'
  },
  'helpvar url_delete' => {
    'lastUpdated' => '1231362117',
    'message' => 'Der URL zum Löschen des aktuellen Albums.'
  },
  'helpvar url_edit' => {
    'lastUpdated' => '1231362131',
    'message' => 'Der URL zum Bearbeiten des aktuellen Albums.'
  },
  'helpvar url_listAlbums' => {
    'lastUpdated' => '1229371451',
    'message' => 'Der URL zur Ansicht der Albenliste der übergeordneten Galerie.'
  },
  'helpvar url_listAlbumsRss' => {
    'lastUpdated' => '1229371503',
    'message' => 'Der URL zum RSS-Feed der Albenliste der übergeordneten Galerie.'
  },
  'helpvar url_listFilesForCurrentUser' => {
    'lastUpdated' => '1229993399',
    'message' => 'Der URL zur Dateienliste des aktuellen Benutzers, die Teil der übergeordneten Galerie ist.'
  },
  'helpvar url_listFilesForOwner' => {
    'lastUpdated' => '1231362159',
    'message' => 'Der URL zur "Mein Album"-Ansicht des Benutzers, dem das aktuelle Album gehört.'
  },
  'helpvar url_search' => {
    'lastUpdated' => '1229371752',
    'message' => 'Der URL zur Such-Ansicht der übergeordneten Galerie.'
  },
  'helpvar url_slideshow' => {
    'lastUpdated' => '1231362170',
    'message' => 'Der URL zur Diashow für das aktuelle Album.'
  },
  'helpvar url_thumbnails' => {
    'lastUpdated' => '1231362181',
    'message' => 'Der URL zur Ansicht der Vorschaubilder für das aktuelle Album.'
  },
  'helpvar url_viewRss' => {
    'lastUpdated' => '1231362088',
    'message' => 'Der URL zum RSS-Feed für das aktuelle Album.'
  },
  'helpvar url_yes' => {
    'lastUpdated' => '1229372169',
    'message' => 'Bestätigen Sie das Löschen dieses Albums!'
  },
  'return to album' => {
    'lastUpdated' => '1244063258',
    'message' => 'Zurück zum Album'
  },
  'rotate left' => {
    'lastUpdated' => '1271834035',
    'message' => '90° links'
  },
  'rotate right' => {
    'lastUpdated' => '1271834048',
    'message' => '90° rechts'
  },
  'save' => {
    'lastUpdated' => '1201607200',
    'message' => 'Speichern'
  },
  'save message' => {
    'lastUpdated' => '1229712933',
    'message' => 'Die Einstellungen für das Album wurden gespeichert. <a href="%s">Zurück zum Album</a>'
  },
  'template add' => {
    'lastUpdated' => '1235676591',
    'message' => 'Album hinzufügen'
  },
  'template addArchive body' => {
    'lastUpdated' => '1229106714',
    'message' => 'Dieses Feld akzeptiert Zip- und Tar/Gzip-Archive.'
  },
  'template addArchive title' => {
    'lastUpdated' => '1229106566',
    'message' => 'Zip-Archiv hinzufügen'
  },
  'template album thumbnail alt' => {
    'lastUpdated' => '1238016773',
    'message' => 'Vorschau Thumbnail'
  },
  'template assetName' => {
    'lastUpdated' => '1229106770',
    'message' => 'Album'
  },
  'template delete message' => {
    'lastUpdated' => '1229106813',
    'message' => 'Sind Sie sicher, dass Sie dieses Album löschen wollen?'
  },
  'template delete no' => {
    'lastUpdated' => '1229107284',
    'message' => 'Nein'
  },
  'template delete yes' => {
    'lastUpdated' => '1229107300',
    'message' => 'Ja'
  },
  'template edit' => {
    'lastUpdated' => '1235676601',
    'message' => 'Album bearbeiten'
  },
  'template file creationDate' => {
    'lastUpdated' => '1230110461',
    'message' => 'Erstellt am'
  },
  'template file numberOfComments' => {
    'lastUpdated' => '1230126199',
    'message' => 'Kommentar(e)'
  },
  'template upload archive' => {
    'lastUpdated' => '1229108720',
    'message' => 'Zip-Archiv'
  },
  'template upload single' => {
    'lastUpdated' => '1229108736',
    'message' => 'Einzelne Datei'
  },
  'template upload type' => {
    'lastUpdated' => '1229108757',
    'message' => 'Art des Uploads'
  },
  'template url' => {
    'lastUpdated' => '1229108848',
    'message' => 'Album'
  },
  'template url_addDescription' => {
    'lastUpdated' => '1238016801',
    'message' => 'Beschreibung hinzufügen'
  },
  'template url_addPhoto' => {
    'lastUpdated' => '1229108891',
    'message' => 'Foto hinzufügen'
  },
  'template url_delete' => {
    'lastUpdated' => '1229108881',
    'message' => 'Album löschen'
  },
  'template url_edit' => {
    'lastUpdated' => '1229108905',
    'message' => 'Album bearbeiten'
  },
  'template url_slideshow' => {
    'lastUpdated' => '1229108919',
    'message' => 'Diashow'
  },
  'template url_thumbnails' => {
    'lastUpdated' => '1229108931',
    'message' => 'Vorschaubilder'
  },
  'template use as thumbnail' => {
    'lastUpdated' => '1235678511',
    'message' => 'Als Titelbild verwenden'
  },
  'what next' => {
    'lastUpdated' => '1229108965',
    'message' => 'Nächster Schritt?'
  }
}
;

1;
